@@ -537,7 +537,7 @@ ods_method_list = [func for func in dir(ODS) if callable(getattr(ODS, func)) and
 
 
 class OMFITods(OMFITobject, ODS):
-    def __init__(self, filename, **kw):
+    def __init__(self, filename, ods=None, **kw):
         ODS_kw = function_arguments(ODS.__init__)[1]
         for kwarg in list(kw.keys()):
             if kwarg in ODS_kw:
@@ -545,7 +545,10 @@ class OMFITods(OMFITobject, ODS):
         OMFITobject.__init__(self, filename, **kw)
         self.dynaLoad = False
         ODS.__init__(self, **ODS_kw)
-        self.dynaLoad = True
+        if ods is not None:
+            self.update(ods)
+        else:
+            self.dynaLoad = True
 
     def __getstate__(self):
         from omas.omas_core import omas_dictstate
