@@ -120,7 +120,9 @@ def find_active_kstar_probes(shot, allowed_probes=None):
 # Data loading tools
 # noinspection PyBroadException
 @make_available_if(compare_version(imas_version, '3.25.0') >= 0)  # Might actually be 3.24.X. Close enough for now.
-def load_data_langmuir_probes_kstar(ods, shot, probes=None, allowed_probes=None, tstart=0, tend=10, dt=0.0002, overwrite=False):
+def load_data_langmuir_probes_kstar(
+    ods, shot, probes=None, allowed_probes=None, tstart=0, tend=10, dt=0.0002, overwrite=False, quantities=None
+):
     """
     Downloads LP probe data from MDSplus and loads them to the ODS
 
@@ -150,6 +152,13 @@ def load_data_langmuir_probes_kstar(ods, shot, probes=None, allowed_probes=None,
     :param overwrite: bool
         Download and write data even if they already are present in the ODS.
 
+    :param quantities: list of strings [optional]
+        List of quantities to gather. None to gather all available. Options are:
+        ion_saturation_current
+        Since KSTAR has only one option at the moment, this keyword is ignored,
+        but is accepted to provide a consistent call signature compared to similar
+        functions for other devices.
+
     :return: ODS instance
         The data are added in-place, so catching the return is probably unnecessary.
     """
@@ -159,10 +168,15 @@ def load_data_langmuir_probes_kstar(ods, shot, probes=None, allowed_probes=None,
     ensure_consistent_experiment_info(ods, device, shot)
 
     # Make sure the ODS already has probe positions in it
+    hw_ready = True
     try:
-        assert is_numeric(ods['langmuir_probes.embedded[0].position.r'])
-        assert ods['langmuir_probes.embedded[0].name'] == '1'
+        if not is_numeric(ods['langmuir_probes.embedded[0].position.r']):
+            hw_ready = False
+        if 'name' not in ods['langmuir_probes.embedded.0']:
+            hw_ready = False
     except Exception:
+        hw_ready = False
+    if not hw_ready:
         setup_langmuir_probes_hardware_description_kstar(ods, shot)
 
     # Select probes to gather
