@@ -154,8 +154,8 @@ class OMFITtglf_eig_spectrum(OMFITdataset, OMFITascii):
         with warnings.catch_warnings():
             # We don't care if matplotlib has an underflow while drawing
             warnings.filterwarnings('ignore', category=RuntimeWarning, message='underflow*')
-            axs[0].set_yscale('symlog', linthreshy=0.01)
-            axs[1].set_yscale('symlog', linthreshy=0.01)
+            axs[0].set_yscale('symlog', linthresh=0.01)
+            axs[1].set_yscale('symlog', linthresh=0.01)
             axs[1].set_ylabel('Frequency $\\omega$')
             axs[1].axhline(0, color='gray', ls='--')
             axs[1].set_xlabel('$k_\\perp \\rho$')
