@@ -1241,6 +1241,7 @@ def is_localhost(server, looseCheck=True):
     :return: server that is localhost, otherwise False
     """
     server_ = tolist(evalExpr(server))
+
     for server in server_:
         if (
             'MainSettings' in OMFIT
@@ -1267,6 +1268,60 @@ def is_localhost(server, looseCheck=True):
 
 utils_base.is_localhost = is_localhost
 
+
+server_picker_cache = dict()
+
+
+def server_picker(root, MainSettings):
+    """
+    Picks appropriate server with managed GA software for a known device
+    Unknown devices will default to a default GA server, which currently
+    is iris.
+    Previous servers are cached
+
+    :param root: reference to the root namespace for the specified module
+
+    :param MainSettings: reference to the MainSettings in the OMFIT namespace
+    """
+    try:
+        experiment_branch = root['SETTINGS']['EXPERIMENT']
+    except KeyError:
+        experiment_branch = MainSettings['EXPERIMENT']
+
+    device = experiment_branch['device']
+
+    if device in server_picker_cache:
+        return server_picker_cache[device]
+
+    if is_localhost('iris'):
+        server_picker_cache[device] = 'iris'
+    elif is_localhost('omega'):
+        server_picker_cache[device] = 'omega'
+    elif is_localhost(['nx', 'portal', 'sunfire'], looseCheck=True):
+        server_picker_cache[device] = 'portal'
+    else:
+        # The decision for server is device dependent
+        if is_device(experiment_branch['device'], 'DIII-D') and MainSettings['SERVER']['GA_username']:
+            server_picker_cache[device] = 'iris'
+        elif is_device(experiment_branch['device'], ['JET', 'MAST']) and MainSettings['SERVER']['CCFE_username']:
+            if is_localhost('freia'):
+                server_picker_cache[device] = 'freia'
+            else:
+                server_picker_cache[device] = 'heimdall'
+        elif is_device(experiment_branch['device'], 'CMOD') and MainSettings['SERVER']['MIT_username']:
+            server_picker_cache[device] = 'cmodws'
+        elif is_device(experiment_branch['device'], 'KSTAR') and MainSettings['SERVER']['KFE_username']:
+            server_picker_cache[device] = 'ukstar'
+        elif is_device(experiment_branch['device'], 'TCV') and MainSettings['SERVER']['EPFL_username']:
+            server_picker_cache[device] = 'lac'
+        elif MainSettings['SERVER']['GA_username']:  # Unkown Device but valid GA credentials
+            server_picker_cache[device] = 'iris'
+        else:
+            raise ValueError('OMFIT Managed Code needs to be run on a known host')
+
+    return server_picker_cache[device]
+
+
 # overwite functions from omfit_classes.utils_base and add some from omfit_classes.utils_fusion
 for _k in [is_localhost, is_server, is_institution, is_device, tokamak]:
     _available_to_user_util(_k)
